Random Utilities, authentication, plain-text appender.
Random Utilities, authentication, plain-text appender.
Checker function for the append algorithm (partial of standard-check).
Checker function for the append algorithm (partial of `standard-check`).
Default character set (as vector) used for random salt generation.
Default character set (as vector) used for random salt generation.
Default encryption options (empty map).
Default encryption options (empty map).
Default length of random salt strings generated for {{RND}} placeholders.
Default length of random salt strings generated for `{{RND}}` placeholders.
(encrypt plain)(encrypt plain options)(encrypt plain options settings)Append the given prefix and/or suffix to a password.
Append the given prefix and/or suffix to a password.
Handler map for the append algorithm, providing :encrypt-fn and :check-fn.
Handler map for the append algorithm, providing `:encrypt-fn` and `:check-fn`.
(parse-random v charset)Expands {{RND}} / {{RND n}} placeholders in string v.
Expands `{{RND}}` / `{{RND n}}` placeholders in string `v`.
Regex matching {{RND}} or {{RND n}} placeholders in prefix/suffix strings.
Regex matching `{{RND}}` or `{{RND n}}` placeholders in prefix/suffix strings.
Keys selected from options for the append operation.
Keys selected from options for the append operation.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |