io.randomseed.utils.auth.algo.append

Random Utilities, authentication, plain-text appender.

Random Utilities, authentication, plain-text appender.
raw docstring

checkclj

Checker function for the append algorithm (partial of standard-check).

Checker function for the append algorithm (partial of `standard-check`).
sourceraw docstring

default-charsetclj

Default character set (as vector) used for random salt generation.

Default character set (as vector) used for random salt generation.
sourceraw docstring

default-optionsclj

Default encryption options (empty map).

Default encryption options (empty map).
sourceraw docstring

default-random-lengthclj

Default length of random salt strings generated for {{RND}} placeholders.

Default length of random salt strings generated for `{{RND}}` placeholders.
sourceraw docstring

encryptclj

(encrypt plain)
(encrypt plain options)
(encrypt plain options settings)

Append the given prefix and/or suffix to a password.

Append the given prefix and/or suffix to a password.
sourceraw docstring

handlerclj

Handler map for the append algorithm, providing :encrypt-fn and :check-fn.

Handler map for the append algorithm, providing `:encrypt-fn` and `:check-fn`.
sourceraw docstring

parse-randomclj

(parse-random v charset)

Expands {{RND}} / {{RND n}} placeholders in string v.

Expands `{{RND}}` / `{{RND n}}` placeholders in string `v`.
sourceraw docstring

re-rndclj

Regex matching {{RND}} or {{RND n}} placeholders in prefix/suffix strings.

Regex matching `{{RND}}` or `{{RND n}}` placeholders in prefix/suffix strings.
sourceraw docstring

required-keysclj

Keys selected from options for the append operation.

Keys selected from options for the append operation.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries